@@ -275,7 +275,7 @@ class program(object):
         d = self.gen_args(*args, **kwargs)
         stdout_filename = unique_filename_in(ex.working_directory)
         stderr_filename = unique_filename_in(ex.working_directory)
-        cmds = ["bsub","-cwd",ex.working_directory,"-o",stdout_filename,"-e",stderr_filename,
+        cmds = ["bsub","-cwd",ex.remote_working_directory,"-o",stdout_filename,"-e",stderr_filename,
                 "-K","-r"] + d["arguments"]
         class Future(object):
             def __init__(self):
@@ -292,7 +292,8 @@ class program(object):
             return_code = sp.wait()
             stdout = None
             stderr = None
-            while not(os.path.exists(os.path.join(ex.working_directory, stdout_filename))):
+            while not(os.path.exists(os.path.join(ex.working_directory, stdout_filename)) and
+                      os.path.exists(os.path.join(ex.working_Directory, stderr_filename))):
                 pass # We need to wait until the files actually show up
             with open(os.path.join(ex.working_directory,stdout_filename), 'r') as fo:
                 stdout = fo.readlines()
@@ -396,7 +397,7 @@ class Execution(object):
 
 
 @contextmanager
-def execution(lims = None, description=""):
+def execution(lims = None, description="", remote_working_directory=None):
     """Create an ``Execution`` connected to the given MiniLIMS object.
     
     ``execution`` is a ``contextmanager``, so it can be used in a ``with``
@@ -422,10 +423,29 @@ def execution(lims = None, description=""):
         print ex.id
 
     will print the execution ID the ``with`` block ran as.
+
+    On some clusters, such as VITAL-IT in Lausanne, the path to the
+    current directory is different on worker nodes where batch jobs
+    run than on the nodes from which jobs are submitted.  For
+    instance, if you are working in /scratch/abc on your local node,
+    the worker nodes might mount the same directory as
+    /nfs/boris/scratch/abc.  In this case, the lsf method of bound
+    programs would not work correctly.
+
+    If this is the case, you can pass the equivalent directory on
+    worker nodes as *remote_working_directory*.  In the example above,
+    an execution may create a directory lK4321fdr21 in /scratch/abc.
+    On the worker node, it would be /nfs/boris/scratch/abc/lK4321fd21,
+    so you pass /nfs/boris/scratch/abc as *remote_working_directory*.
     """
     execution_dir = unique_filename_in(os.getcwd())
     os.mkdir(os.path.join(os.getcwd(), execution_dir))
     ex = Execution(lims,os.path.join(os.getcwd(), execution_dir))
+    if remote_working_directory == None:
+        ex.remote_working_directory = ex.working_directory
+    else:
+        ex.remote_working_directory = os.path.join(remote_working_directory,
+                                                   execution_dir)
     os.chdir(os.path.join(os.getcwd(), execution_dir))
     exception_string = None
     try:
